@@ -1,8 +1,8 @@
 package Mite::MakeMaker;
-use Mite::Miteception '-Basic';
+use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 ##-
 
